Summary:        Software watchdog
Name:           watchdog
Version:        5.16
Release:        %mkrel 5
Group:          System/Kernel and hardware
License:        GPLv2+ & QPL
URL:            https://sourceforge.net/projects/watchdog/
Source0:        https://downloads.sourceforge.net/watchdog/%{name}-%{version}.tar.gz
Source4:        watchdog.service
Source5:        watchdog-ping.service
# Fixes building on glibc without RPC.  Sent upstream 2019-02-06.
Patch1:         0001-Choose-libtirpc-or-another-RPC-library-for-XDR-heade.patch
# Fixes potentional mem leak
Patch2:         0002-mem-leak-verbose.patch
Requires:       kernel
BuildRequires:  kernel-headers
BuildRequires:  glibc-devel
BuildRequires:  pkgconfig(libtirpc)

%description
Watchdog monitors various aspects of a machine to ensure that is has not
locked up.  In the event that a machine has locked up, watchdog will invoke
a reboot of the system.

%prep
%autosetup -p1

%build
autoreconf -vfi
%configure \
    CFLAGS="%{__global_cflags} -I/usr/include/tirpc" \
    LDFLAGS="%{__global_ldflags} -ltirpc"
%make_build

mv README README.orig
iconv -f ISO-8859-1 -t UTF-8 < README.orig > README

%install
install -d -m0755 %{buildroot}%{_sysconfdir}
install -d -m0755 %{buildroot}%{_sysconfdir}/watchdog.d
%make_install
install -Dp -m0644 %{SOURCE4} %{buildroot}%{_unitdir}/watchdog.service
install -Dp -m0644 %{SOURCE5} %{buildroot}%{_unitdir}/watchdog-ping.service
install -Dd -m0755 %{buildroot}%{_libexecdir}/watchdog/scripts
rm %{name}.sysconfig

%check
make check

%post
%_post_service watchdog
%_post_service watchdog-ping

%preun
%_preun_service watchdog
%_preun_service watchdog-ping

%triggerun -- watchdog < 5.16-3
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply watchdog
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save watchdog >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del watchdog >/dev/null 2>&1 || :
/bin/systemctl try-restart watchdog.service >/dev/null 2>&1 || :
/bin/systemctl try-restart watchdog-ping.service >/dev/null 2>&1 || :

%files
%doc AUTHORS ChangeLog NEWS README TODO README.watchdog.ipmi examples/
%attr(0755,root,root) %{_sbindir}/watchdog
%attr(0755,root,root) %{_sbindir}/wd_keepalive
%attr(0755,root,root) %{_sbindir}/wd_identify
%{_mandir}/man5/watchdog.conf.5*
%{_mandir}/man8/watchdog.8*
%{_mandir}/man8/wd_keepalive.8*
%{_mandir}/man8/wd_identify.8*
%config(noreplace) %{_sysconfdir}/watchdog.conf
%{_unitdir}/watchdog.service
%{_unitdir}/watchdog-ping.service
%dir %{_libexecdir}/watchdog
%{_libexecdir}/watchdog/scripts
%{_sysconfdir}/watchdog.d


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 5.16-5.mga10
+ Revision: 2222163
- Mageia 10 Mass Rebuild

* Sun Apr 14 2024 daviddavid <daviddavid> 5.16-4.mga10
+ Revision: 2057384
- use our systemd macros

* Sun Apr 14 2024 papoteur <papoteur> 5.16-3.mga10
+ Revision: 2057380
- port to systemd usage

* Sat Mar 19 2022 umeabot <umeabot> 5.16-2.mga9
+ Revision: 1800087
- Mageia 9 Mass Rebuild

* Tue Dec 14 2021 neoclust <neoclust> 5.16-1.mga9
+ Revision: 1762035
- New version 5.16: Fixes memleak (mga#29576)

* Thu Nov 26 2020 tv <tv> 5.15-3.mga8
+ Revision: 1649518
- fix building with libtirpc
+ danf <danf>
- Switch URLs from http: to https:

* Tue Feb 11 2020 umeabot <umeabot> 5.15-2.mga8
+ Revision: 1489242
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Sep 15 2018 daviddavid <daviddavid> 5.15-1.mga7
+ Revision: 1259070
- new version: 5.15
- enable libtirpc support

* Thu Feb 04 2016 umeabot <umeabot> 5.13-5.mga6
+ Revision: 936152
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 5.13-4.mga5
+ Revision: 740850
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 5.13-3.mga5
+ Revision: 690275
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 5.13-2.mga4
+ Revision: 526626
- Mageia 4 Mass Rebuild

* Thu Jun 06 2013 dams <dams> 5.13-1.mga4
+ Revision: 438375
- new version 5.13

* Mon Jan 14 2013 umeabot <umeabot> 5.12-2.mga3
+ Revision: 385640
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 ennael <ennael> 5.12-1.mga3
+ Revision: 343654
- new version 5.12

* Sat Apr 28 2012 tmb <tmb> 5.9-2.mga2
+ Revision: 233894
- Require rpm-helper >= 0.24.8-1 for systemd support

* Tue Oct 25 2011 dmorgan <dmorgan> 5.9-1.mga2
+ Revision: 157965
- New version 5.9
  Remove merged patch
  Add systemd support

* Mon Oct 24 2011 dmorgan <dmorgan> 5.7-2.mga2
+ Revision: 157663
- Remove old rpm stuffs
+ ennael <ennael>
- add missing buildrequire
- clean spec file
- imported package watchdog


* Wed Dec 08 2010 Oden Eriksson <oeriksson@mandriva.com> 5.7-2mdv2011.0
+ Revision: 615432
- the mass rebuild of 2010.1 packages

* Wed Jan 06 2010 Frederik Himpe <fhimpe@mandriva.org> 5.7-1mdv2010.1
+ Revision: 486793
- update to new version 5.7

* Sun Sep 20 2009 Thierry Vignaud <tv@mandriva.org> 5.6-2mdv2010.0
+ Revision: 445737
- rebuild

* Sun Mar 22 2009 Frederik Himpe <fhimpe@mandriva.org> 5.6-1mdv2009.1
+ Revision: 360398
- Update to new version 5.6
- Remove unneeded patches and hacks
- Add patch fixing build with -Werror=format-security

* Sun Jul 20 2008 Oden Eriksson <oeriksson@mandriva.com> 5.4-2mdv2009.0
+ Revision: 239010
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Aug 17 2007 David Walluck <walluck@mandriva.org> 5.4-1mdv2008.0
+ Revision: 65319
- 5.4
- add udev support
- rediff initscript patch

* Wed Jun 20 2007 David Walluck <walluck@mandriva.org> 5.3.1-1mdv2008.0
+ Revision: 41716
- spec cleanup
- fix PreReq use
- 5.3.1
- use pristine source
- remove unneeded patches
- own /dev/watchdog
- create /dev/watchdog before service start
- more explicit file list
- LSB init support


* Tue May 10 2005 Frederic Lepied <flepied@mandriva.com> 5.2.3-2mdk
- fix build on x86_64

* Tue Jun 03 2003 Frederic Lepied <flepied@mandrakesoft.com> 5.2.3-1mdk
- 5.2.3
- open /dev/watchdog by default

* Thu Jun 27 2002 Lenny Cartier <lenny@mandrakesoft.com> 5.2-2mdk
- patch1: patch sundries.cc

* Fri Sep 14 2001 Lenny Cartier <lenny@mandrakesoft.com> 5.2-1mdk
- added by Oden Eriksson <oden.eriksson@kvikkjokk.net> :
	- initial cooker contrib
	- update to 5.2
	- added patch0

* Sat Jun 24 2000 Soenke J. Peters <peters+rpm@simprovement.com>
- RedHat Build

* Wed Apr 19 2000 Marc Christensen <marc@calderasystems.com>
- Initial Caldera Build

